.. include:: ../README.rst

.. important:: In case of questions/suggestions/problems/etc. feel free to contact `Emil Michels <https://https://www.io-warnemuende.de/emil-michels-en.html/>`_, any time.


.. toctree::
   :maxdepth: 1
   :caption: Contents

   General usage <usage>
   API <source/modules>

.. toctree::
   :maxdepth: 1
   :caption: Links

    Code <"https://github.com/DAM-CTD-Software/ctdam">
    PyPi <https://www.pypi.org/project/ctdam>
    DAM Underway Project <https://www.allianz-meeresforschung.de/kernbereiche/datenmanagement-und-digitalisierung#unterwegs>
    IOW <https://iow.de/en_index.html>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
